@@ -1,4 +1,4 @@
-(* $Id: pa_s.ml,v 1.3 2007/01/03 09:42:46 deraugla Exp $ *)
+(* $Id: pa_s.ml,v 1.5 2007/07/16 09:03:07 deraugla Exp $ *)
 
 #load "pa_extend.cmo";
 #load "q_MLast.cmo";
@@ -66,7 +66,7 @@ value mkuminpat loc arg =
   | _ -> invalid_arg "mkuminpat" ]
 ;
 
-IFDEF CAMLP4S THEN declare
+IFDEF CAMLP5 THEN declare
 value merge_couple loc1 loc2 =
   Stdpp.sub_loc loc1 0 (Stdpp.last_pos loc2 - Stdpp.first_pos loc1)
 ;
@@ -439,7 +439,10 @@ EXTEND
   type_declaration:
     [ [ n = type_patt; tpl = LIST0 type_parameter; "="; tk = ctyp;
         cl = LIST0 constrain ->
-          (n, tpl, tk, cl) ] ]
+          IFDEF CAMLP5_4_02 THEN
+            {MLast.tdNam = n; MLast.tdPrm = tpl; MLast.tdPrv = False;
+             MLast.tdDef = tk; MLast.tdCon = cl}
+          ELSE (n, tpl, tk, cl) END ] ]
   ;
   type_patt:
     [ [ n = LIDENT -> (loc, n) ] ]
