@@ -9,12 +9,12 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: go.ml,v 1.31 2007/03/20 15:34:54 deraugla Exp $ *)
+(* $Id: go.ml,v 1.37 2007/07/16 09:03:07 deraugla Exp $ *)
 
 open Ledit;
 open Sys;
 
-value version = "1.13";
+value version = "1.15";
 
 value usage () = (
   prerr_string "Usage: ";
@@ -85,7 +85,7 @@ value string_of_signal =
 value rec read_loop () = (
   try
     let c = input_char stdin in
-    print_a_char c
+    if c = "\n" then print_newline () else print_string c
   with
   [ Break -> () ];
   read_loop ()
