@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: ledit.ml,v 1.33 2007/03/20 13:55:05 deraugla Exp $ *)
+(* $Id: ledit.ml,v 1.36 2007/03/30 06:06:06 deraugla Exp $ *)
 
 #load "pa_local.cmo";
 #load "pa_def.cmo";
@@ -30,6 +30,7 @@ module A :
         value not_ascii_val : t -> option (t * t * t);
         value uppercase : t -> t;
         value lowercase : t -> t;
+        value to_string : t -> string;
         value input : in_channel -> t;
         value read : unit -> t;
         value print : t -> unit;
@@ -67,7 +68,7 @@ module A :
     module Char =
       struct
         type t = string;
-       value of_ascii c = String.make 1 c;
+        value of_ascii c = String.make 1 c;
         value to_ascii c =
            if String.length c = 1 && Char.code c.[0] < 128 then Some c.[0]
            else None
@@ -128,6 +129,7 @@ module A :
                 if Char.code c.[0] < 128 then String.lowercase c else c
               else c ]
         ;
+        value to_string s = s;
         value get_char f =
           match encoding.val with
           [ Ascii | Iso_8859 -> String.make 1 (f ())
@@ -160,7 +162,9 @@ module A :
         ;
         value prerr c = output_string stderr c;
         value prerr_backsp c = (
-          if Char.code c.[0] >= 228 && Char.code c.[0] <= 233 then
+          if encoding.val = Utf_8 &&
+             Char.code c.[0] >= 228 && Char.code c.[0] <= 233
+          then
             (* hack for Chinese; it seems that terminals (at least
                "konsole" and "xterm") need 2 backspaces to put the
                cursor on the glyph. *)
@@ -202,9 +206,6 @@ module A :
   end
 ;
 
-type a_char = A.Char.t;
-value print_a_char = A.Char.print;
-
 DEFINE CTRL(x) = EVAL (Char.chr (Char.code x - (Char.code 'a' - 1)));
 DEFINE META(x) = EVAL (Char.chr (Char.code x + 128));
 DEFINE DEL = '\127';
@@ -783,7 +784,7 @@ value reverse_search_history st =
         then
           find_line (cnt + 1, Cursor.peek st.history) str
         else (bell (); (cnt, fstr))
-      else if A.String.get str istr != A.String.get fstr ifstr then
+      else if A.String.get str istr <> A.String.get fstr ifstr then
         find_rec (ifstr + 1) 0
       else find_rec (ifstr + 1) (istr + 1)
   in
@@ -1147,13 +1148,13 @@ and close_histfile () =
   | None -> () ]
 ;
 
-value (set_prompt, get_prompt, input_char) =
+value (set_prompt, get_prompt, input_a_char) =
   let prompt = ref ""
   and buff = ref A.String.empty
   and ind = ref 1 in
   let set_prompt x = prompt.val := x
   and get_prompt () = prompt.val
-  and input_char ic =
+  and input_a_char ic =
     if ic != stdin then A.Char.input ic
     else (
       if ind.val > A.String.length buff.val then (
@@ -1176,5 +1177,7 @@ value (set_prompt, get_prompt, input_char) =
       c
     )
   in
-  (set_prompt, get_prompt, input_char)
+  (set_prompt, get_prompt, input_a_char)
 ;
+
+value input_char ic = A.Char.to_string (input_a_char ic);
