@@ -9,12 +9,9 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: ledit.mli,v 1.10 2007/03/20 13:55:06 deraugla Exp $ *)
+(* $Id: ledit.mli,v 1.11 2007/03/21 02:38:16 deraugla Exp $ *)
 
-type a_char = 'abstract;
-
-value input_char : in_channel -> a_char;
-value print_a_char : a_char -> unit;
+value input_char : in_channel -> string;
 
 value set_prompt : string -> unit;
 value get_prompt : unit -> string;
